Summary: A utility for getting files from remote servers (FTP, HTTP, and others)
Name: recutils
Version: 1.4
Release: 1
License: MIT
Group: Applications/Internet
Source0: ftp://ftp.gnu.org/gnu/recutils/%{name}-%{version}.tar.gz
Source1: ftp://ftp.gnu.org/gnu/recutils/%{name}-%{version}.tar.gz.sig
URL: http://www.gnu.org/software/recutils/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: info, /sbin/install-info
BuildRequires: curl-devel >= 7.19.7-1
BuildRequires: gettext
BuildRequires: mdbtools-libs >= 0.6.cvs20051109-1
BuildRequires: mdbtools-devel >= 0.6.cvs20051109-1

Requires: info, /sbin/install-info
Requires: curl >= 7.19.7-1
Requires: gettext
Requires: mdbtools-libs >= 0.6.cvs20051109-1

%define _libdir64 %{_prefix}/lib64

%description
GNU Recutils is a set of tools and libraries to access human-editable,
text-based databases called recfiles. The data is stored as a sequence of
cords, each record containing an arbitrary number of named fields.
Some advanced capabilities usually found in other data storage systems are
supported: data types, data integrity (keys, mandatory fields, etc) as well as
the ability of records to refer to other records (sort of foreign keys).
Despite its simplicity, recfiles can be used to store medium-sized databases. 

The library is available as 32-bit and 64-bit.


%package devel
Summary: Files needed for building applications with %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: curl-devel >= 7.19.7-1
Requires: gettext
Requires: mdbtools-libs >= 0.6.cvs20051109-1
Requires: mdbtools-devel >= 0.6.cvs20051109-1

%description devel
GNU Recutils is a set of tools and libraries to access human-editable,
text-based databases called recfiles. The data is stored as a sequence of
cords, each record containing an arbitrary number of named fields.
Some advanced capabilities usually found in other data storage systems are
supported: data types, data integrity (keys, mandatory fields, etc) as well as
the ability of records to refer to other records (sort of foreign keys).
Despite its simplicity, recfiles can be used to store medium-sized databases. 

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%prep
%setup -q 
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CONFIG_SHELL=/usr/bin/ksh
export CONFIG_ENV_ARGS=/usr/bin/ksh

export CC="xlc_r"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --enable-shared --disable-static
make %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --enable-shared --disable-static
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
gzip --best ${RPM_BUILD_ROOT}%{_infodir}/*.info

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/librec.a ${RPM_BUILD_ROOT}%{_libdir64}/librec.so*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/$dir
    cd usr/$dir
    ln -sf ../..%{_prefix}/$dir/* .
    cd -
  done
)


%post
/sbin/install-info --quiet --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz || :


%preun
if [ "$1" = 0 ]; then
    /sbin/install-info --quiet --info-dir=%{_infodir} --delete %{_infodir}/%{name}.info.gz || :
fi


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc 32bit/AUTHORS 32bit/COPYING 32bit/NEWS 32bit/README
%{_bindir}/*
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
%{_mandir}/man1/*
%{_infodir}/*.info*
%{_datadir}/%{name}
%{_datadir}/locale/*/*/*
/usr/bin/*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%defattr(-,root,system)
%doc 32bit/AUTHORS 32bit/COPYING 32bit/NEWS 32bit/README
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Fri Nov 04 2011 Michael Perzl <michael@perzl.org> - 1.4-1
- updated to version 1.4

* Mon Feb 21 2011 Michael Perzl <michael@perzl.org> - 1.3-1
- first version for AIX V5.1 and higher
